#

##

    	monitors

    	possibilities
    		( ) atatus
    			https://www.atatus.com/

    		( ) Chartbeat
    			https://chartbeat.com/products/dashboards/

    		( ) Cloudflare
    			https://www.cloudflare.com/

    		( ) Flask Analytics
    			https://github.com/citruspi/Flask-Analytics

    		( ) Google Analytics

    		( ) Go Squared
    			https://www.gosquared.com/
    				https://www.gosquared.com/analytics/

    		( ) Graphana

    		( ) matomo
    			https://matomo.org/

    		( ) Mixpanel
    			https://mixpanel.com/

    		( ) woopra
    			https://www.woopra.com/